@@ -41,6 +41,8 @@ def get_error_decorator(error_mapper):
 
     Definition of the decorator:
 
+    .. code-block:: python
+
         decorator(error_name, namespace=())
 
     The decorator accepts a name of the DBus error and optionally
@@ -49,6 +51,8 @@ def get_error_decorator(error_mapper):
 
     Usage:
 
+    .. code-block:: python
+
         # Create an error mapper.
         error_mapper = ErrorMapper()
 
@@ -137,7 +141,7 @@ class ErrorRule(AbstractErrorRule):
         """Create a new error rule.
 
         The rule will return the Python type exception_type
-        for the the DBue error error_name.
+        for the DBue error error_name.
 
         The rule will return the DBue name error_name for
         the Python type exception_type
